@@ -33,12 +33,16 @@ using namespace std;
 class Binder : public BayonneBinder, ScriptChecks
 {
 private:
+	char altconfig[MAX_PATHNAME];
+	unsigned altlen;
+
         void attach(ScriptInterp *interp);
         void detach(ScriptInterp *interp);
 	bool select(ScriptInterp *interp);
         bool reload(ScriptCompiler *img);
 	Name *service(ScriptImage *img, ScriptInterp *interp, const char *sid);
 	void down(void);
+	const char *altPath(const char *path);
 
 public:
         Binder();
