@@ -127,7 +127,7 @@ bool Bayonne::loadPlugin(const char *path)
 #ifdef	WIN32
 #ifdef	HAVE_TESTING
         if(!prefix && provision_test)
-#ifdef  _DEBUG
+#ifdef  NDEBUG
                 prefix = "DEBUG";
 #else
                 prefix = "RELEASE";
@@ -257,10 +257,83 @@ bool Bayonne::loadMonitor(const char *path)
         return true;                
 }
 
+#ifdef	HAVE_CAPAUDIO
+bool Bayonne::loadAudio(const char *path)
+{
+        char pathbuf[256];
+        const char *cp, *kv;
+	const char *prefix = NULL;
+        DSO *dso;
+
+#ifdef	WIN32
+#ifdef	HAVE_TESTING
+        if(!prefix && provision_test)
+#ifdef  _DEBUG
+                prefix = "DEBUG";
+#else
+                prefix = "RELEASE";
+#endif 
+#endif
+	if(!prefix)
+		prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Audio";
+#else
+        char prefixbuf[256];
+
+#ifdef	HAVE_TESTING
+        if(!prefix && provision_test && !strchr(path, '/'))
+        {
+                snprintf(prefixbuf, sizeof(prefixbuf),
+                        "%s/modules/%s/.libs", SOURCE_FILES, path);
+                if(!isDir(prefixbuf))  
+                        snprintf(prefixbuf, sizeof(prefixbuf),
+                                "%s/modules/%s", SOURCE_FILES, path);
+                prefix = prefixbuf;
+        } 
+#endif
+	if(!prefix)
+		prefix = LIBDIR_FILES;
+#endif
+
+#ifdef  WIN32
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s." RLL_SUFFIX, prefix, path);
+#else
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s.cap", prefix, path);
+#endif  
+        cp = path;
+        path = pathbuf;
+
+        kv = server->getLast(path);
+        if(kv)
+        {
+                if(!stricmp(kv, "loaded"))
+                        return true;
+		return false;
+	}
+
+        if(!canAccess(path))
+        {
+                errlog("access", "cannot load %s", path);
+                return false;
+        }
+
+        dso = new DSO(path);
+        if(!dso->isValid())
+        {
+                kv = dso->getError();
+                server->setValue(path, kv);
+                errlog("error", "cannot initialize %s", path);
+                return false;
+        }
+        server->setValue(path, "loaded");
+        return true;                
+}
+
+#else
 bool Bayonne::loadAudio(const char *cp)
 {
 	return false;
 }
+#endif
 
 Bayonne::Handler Bayonne::getState(const char *id)
 {
@@ -323,7 +396,7 @@ bool Bayonne::matchDigits(const char *digits, const char *match, bool partial)
 		digits += (len - dlen);
 	}
 
-	while(*match && *digits)
+	while(*match)
 	{
 		inc = true;
 		switch(*match)
@@ -360,11 +433,8 @@ bool Bayonne::matchDigits(const char *digits, const char *match, bool partial)
 			++digits;
 		++match;	
 	}
-        if(*match && !*digits)
-                return partial;
-
-        if(*match && *digits)
-                return false;
+	if(*digits)
+		return partial;
 
 	return true;
 }
@@ -544,8 +614,6 @@ void Bayonne::down(void)
 ScriptCompiler *Bayonne::reload(void)
 {
 	static Mutex lock;
-	const char *cp;
-	char buffer[32];
 
 	ScriptCompiler *img;
 
@@ -565,23 +633,6 @@ ScriptCompiler *Bayonne::reload(void)
 		img->loadPrefix("config", "~bayonne/config");
 #endif
 
-#ifdef  SCRIPT_DEFINE_TOKENS
-        const char *const *list = server->getList("definitions");
-        img->compileDefinitions("site.def");
-        while(list && *list)
-        {
-                img->compileDefinitions(*list);
-                ++list;
-        }
-	cp = server->getLast("location");
-	if(cp)
-	{
-		snprintf(buffer, sizeof(buffer), "macros-%s.def", cp);
-		img->compileDefinitions(buffer);
-	}
-	img->compileDefinitions("macros.def");
-#endif
-
 	ScriptBinder::rebuild(img);
 	img->commit();
 	lock.leave();
