@@ -1029,6 +1029,8 @@ void BayonneSession::check(void)
 	Line *line = getLine();
 	Name *scr = getName();
 
+	// if in menu, always enable
+
 	if(state.menu)
 	{
 		dtmf = enableDTMF();
@@ -1041,7 +1043,17 @@ void BayonneSession::check(void)
 		return;
 	}
 
-	if((frame[stack].mask & 0x8) || server->isInput(line))
+	// if input object, always enable
+
+	if(server->isInput(line))
+	{
+		dtmf = enableDTMF();
+		return;
+	}
+
+	// if frame and line enabled, enable...
+
+	if((frame[stack].mask & 0x8) && (line->mask & 0x08))
 	{
 		dtmf = enableDTMF();
 		return;
