@@ -1774,7 +1774,6 @@ bool BayonneSession::stateHangup(Event *event)
 bool BayonneSession::filterPosting(Event *event)
 {
 	BayonneSession *pid;
-	Line *line;
 
 	switch(event->id)
 	{
@@ -1788,9 +1787,6 @@ bool BayonneSession::filterPosting(Event *event)
 	case DTMF_KEYDOWN:
 		if(!dtmf || !dtmf_digits)
 			return false;
-		line = getLine();
-		if(line && !(line->mask & 0x08))
-			return false;
 		digit_count = strlen(dtmf_digits);
 		return true;
 	case STOP_PARENT:
@@ -2097,7 +2093,7 @@ childerr:
 			dtmf_digits[digit_count++] = getChar(event->dtmf.digit);
 			dtmf_digits[digit_count] = 0;
 		}
-		
+
 		if(!state.menu)
 			if(signalScript((signal_t)(event->dtmf.digit + SIGNAL_0)))
 			{
