@@ -26,7 +26,7 @@ our @EXPORT = qw(
 
 );
  
-our $VERSION = '0.02'; 
+our $VERSION = '0.03'; 
 
 # disable buffering
 $|=1;
@@ -160,6 +160,12 @@ sub detach($$) {
 	}
 }
 
+sub post($$$) {
+	my($self, $id, $value) = @_;
+	my $sid = $self->{head}{'SESSION'};
+	print STDOUT "$sid POST $id $value\n";
+}
+
 sub pathname($$) {
 	my($self,$file) = @_;
 	my $prefix = $self->{head}{'PREFIX'};
