@@ -75,6 +75,11 @@ class Libexec:
 			self.args[tmp[0]] = tmp[1]
 		return
 
+	def postSymbol(self, id, value):
+		sid = self.head['SESSION']
+		sys.stdout.write("%s POST %s %s" % (sid, id, value))
+		return		
+
 	def pathname(self, file):
 		ext = self.head['EXTENSION']
 		var = os.environ.get('SERVER_PREFIX')
