@@ -115,6 +115,10 @@ static Keydata::Define engine[] = {
 	{"userid", ""},
 	{"secret", ""},
 	{"timeslots", "32"},
+#ifndef	WIN32
+	{"trunking", "autodetect"},
+	{"protocol", "default"},
+#endif
 	{NULL, NULL}};
 
 #ifdef	WIN32
@@ -520,6 +524,34 @@ bool parseConfig(char **argv)
 	unsigned minslots = 0;
 	bool live = true;
 
+#ifndef WIN32
+	const char *cp;
+
+        cp = keyengine.getLast("trunking");
+        if(cp && !stricmp(cp, "autodetect"))
+	{
+                cp = Process::getEnv("TIMESLOTS");
+		goto setenv;
+	}
+        else if(cp && !stricmp(cp, "default"))
+	{
+                cp = Process::getEnv("TIMESLOTS");
+		goto setenv;
+	}
+
+	cp = keyengine.getLast("protocol");
+	if(cp && !stricmp(cp, "default"))
+	{
+		cp = Process::getEnv("TIMESLOTS");
+		goto setenv;
+	}
+
+	goto retry;
+setenv:
+	if(cp && atoi(cp) > 0)
+		keyengine.setValue("timeslots", cp);
+#endif
+
 retry:
 	if(!*argv)
 		goto skip;
