@@ -22,6 +22,53 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+bool Methods::scrBind(void)
+{
+	char name[32];
+	const char *bind = getValue(NULL);
+	Method handler;
+
+	snprintf(name, sizeof(name), "%sxml", bind);
+	handler = cmd->getHandler(name);
+
+	if(handler == NULL)
+	{
+		error("binding-missing");
+		return true;
+	}
+
+	return execute(handler);
+}
+
+bool Methods::scrBGM(void)
+{
+	const char *bgm = getValue(NULL);
+	BayonneFeeder *feed;
+
+	if(!stricmp(bgm, "off") || !stricmp(bgm, "none") || !*bgm)
+	{
+		setFeeder(NULL);
+		advance();
+		return true;
+	}
+
+	feed = BayonneFeeder::get(bgm);
+	if(!feed)
+	{
+		error("bgm-invalid");
+		return true;
+	}
+
+	if(!setFeeder(feed))
+	{
+		error("bgm-unsupported");
+		return true;
+	}
+
+	advance();
+	return true;
+}
+
 bool Methods::scrTransfer(void)
 {
 	char nbuf[MAX_PATHNAME];
@@ -34,7 +81,7 @@ bool Methods::scrTransfer(void)
 		svr = driver->getLast("outbound");
 
 	if(!svr)
-		svr = getSymbol("session.uri_server");
+		svr = getSymbol("session.server");
 
 	if(!pre)
 		pre = driver->getLast("transfer");
@@ -55,17 +102,16 @@ bool Methods::scrTransfer(void)
 		if(strchr(nbuf, '@'))
 			svr = NULL;
 
-                len = strlen(pre);
-                if(svr && len && !strnicmp(pre, svr, len))
-                        svr += len;
-                else if(!svr && len && !strnicmp(pre, nbuf, len))
-                        pre = "";
-
 		if(svr)
 			snprintf(state.url.buf, sizeof(state.url.buf), "%s%s@%s", pre, nbuf, svr);
 		else
-			snprintf(state.url.buf, sizeof(state.url.buf), "%s%s", pre, nbuf);
+			snprintf(state.url.buf, sizeof(state.url.buf), "%s", nbuf);
 
+		if(*pre && strnicmp(state.url.buf, pre, strlen(pre)))
+		{
+			error("invalid-url");
+			return true;
+		}
 		state.url.ref = state.url.buf;
 		setState(STATE_XFER);
 		return false;
@@ -426,8 +472,8 @@ bool Methods::scrCollect(void)
         if(state.input.interdigit == TIMEOUT_INF)
                 state.input.interdigit = state.timeout;
 
-        if(state.input.lastdigit == TIMEOUT_INF)
-                state.input.lastdigit = state.input.interdigit;   
+	if(state.input.lastdigit == TIMEOUT_INF)
+		state.input.lastdigit = state.input.interdigit;
 
         state.input.exit = getExitKeyword("#");
 
@@ -532,13 +578,13 @@ bool Methods::scrInput(void)
 	if(!state.input.required)
 		state.input.required = state.input.count;
 
-        if(state.input.lastdigit == TIMEOUT_INF)     
-        {
-                if(state.input.exit && *state.input.exit)
-                        state.input.lastdigit = 800; 
-                else
-                        state.input.lastdigit = state.input.interdigit;
-        }
+	if(state.input.lastdigit == TIMEOUT_INF)
+	{
+		if(state.input.exit && *state.input.exit)
+			state.input.lastdigit = 800;
+		else
+			state.input.lastdigit = state.input.interdigit;
+	}
 
 	setState(STATE_INPUT);
 	return false;	
@@ -721,64 +767,6 @@ bool Methods::scrErase(void)
 	return true;
 }	
 
-#ifndef	WIN32
-
-bool Methods::scrLink(void)
-{
-	const char *cp = getAudio(false);
-	const char *dp;
-	const char *se, *de;
-	char buf1[MAX_PATHNAME], buf2[MAX_PATHNAME];
-	
-	if(cp)
-	{
-		slog.error("%s: %s", logname, cp);
-		error("invalid-link");
-		return true;
-	}
-
-	cp = getWritepath(buf1, sizeof(buf1));
-	if(!cp)
-	{
-		error("invalid-source");
-		return true;
-	}
-
-	dp = getWritepath(buf2, sizeof(buf2));	
-	if(!cp)
-	{
-		error("invalid-target");
-		return true;
-	}
-
-	se = strrchr(cp, '.');
-	de = strrchr(dp, '.');
-
-	if(!se || !de)
-	{
-		error("invalid-names");
-		return true;
-	}
-
-	if(stricmp(se, de))
-	{
-		error("filename-mismatch");
-		return true;
-	}
-
-	if(link(cp, dp))
-	{
-		if(!signalScript(SIGNAL_FAIL))
-			error("link-failed");
-		return true;
-	}
-
-	advance();
-	return true;
-}	
-
-#endif
-
 bool Methods::scrMove(void)
 {
 	const char *cp = getAudio(false);
@@ -1039,8 +1027,6 @@ bool Methods::scrRecord(void)
         }
 
 	state.audio.list[0] = getValue(NULL);
-	state.audio.list[1] = getValue(NULL);
-	state.audio.list[2] = NULL;
 
 	state.audio.mode = Audio::modeCreate;
 	if(audio.offset)
@@ -1089,8 +1075,6 @@ bool Methods::scrAppend(void)
         }
 
 	state.audio.list[0] = getValue(NULL);
-	state.audio.list[1] = getValue(NULL);
-	state.audio.list[2] = NULL;
 	state.audio.mode = Audio::modeAppend;
 
 	setState(STATE_RECORD);
