@@ -825,7 +825,8 @@ void Runtime::process(void)
 		fclose(fp);
 	}
 
-	snprintf(buf, sizeof(buf), "%s/%s.ctrl", keypaths.getLast("runfiles"), argv0);
+	snprintf(buf, sizeof(buf), "%s/bayonne.ctrl", keypaths.getLast("runfiles"));
+	slog.debug("fifo=%s", buf);
 	remove(buf);
 	mkfifo(buf, 0770);
 	keypaths.setValue("runfifo", buf);
