@@ -199,6 +199,12 @@ static void loading(void)
 		cp = NULL;
 	if(cp && !stricmp(cp, "none"))
 		cp = NULL;
+
+#ifndef	WIN32
+	if(cp && !stricmp(cp, "autodetect"))
+		cp = Process::getEnv("DRIVER_AUTODETECT");
+#endif
+
 	if(cp && *cp)
 	{
 		driver = BayonneDriver::loadDriver(cp);
@@ -209,16 +215,46 @@ static void loading(void)
 	{
 		driver = NULL;
 		cp = keyengine.getLast("trunking");
+#ifndef	WIN32
+		if(cp && !stricmp(cp, "autodetect"))
+		{
+			cp = Process::getEnv("TRUNKING_AUTODETECT");
+			if(!cp || !*cp)
+				cp = "default";
+		}
+		if(cp && !stricmp(cp, "default"))
+		{
+			cp = Process::getEnv("TRUNKING");
+			if(!cp || !*cp)
+			{
+				cp = keyengine.getLast("protocol");
+				if(cp && !stricmp(cp, "default"))
+				{
+					cp = Process::getEnv("PROTOCOL");
+					if(!cp || !*cp)
+						cp = "soundcard";
+					else
+						cp = "none";
+				}
+				else
+					cp = "none";
+			}
+		}
+#endif
 		if(cp && !stricmp(cp, "no"))
 			cp = NULL;
 		if(cp && !stricmp(cp, "none"))
 			cp = NULL;
-		if(cp)
+		if(cp && *cp)
 			driver = BayonneDriver::loadTrunking(cp);
 		if(driver)
 			loaded = true;
 		
 		cp = keyengine.getLast("protocol");
+#ifndef	WIN32
+		if(cp && !stricmp(cp, "default"))
+			cp = Process::getEnv("PROTOCOL");
+#endif			
 		if(cp && *cp && strnicmp(cp, "no", 2))
 		{
 			pflag = true;
@@ -548,6 +584,28 @@ int main(int argc, char **argv)
                         stop(-1);
                 }
         }
+
+        cp = keyengine.getLast("trunking");
+        if(cp && !stricmp(cp, "autodetect"))
+        {
+                cp = Process::getEnv("DRIVER_AUTODETECT");
+		if(!cp || !*cp)
+			cp = Process::getEnv("TRUNKING_AUTODETECT");
+                if(!cp || !*cp)
+                        cp = Process::getEnv("TRUNKING");
+                if(!cp || !*cp)
+		{
+			cp = keyengine.getLast("protocol");
+			if(cp && !stricmp(cp, "default"))
+			{
+				cp = Process::getEnv("PROTOCOL");
+				if(!cp || !*cp)
+		                        Bayonne::provision_daemon = false;
+			}
+		}
+        }
+
+
 	if(Bayonne::provision_daemon)
 		Process::detach();
 
